@@ -23,17 +23,17 @@ library(extraoperators)
 library(brms)
 library(lme4)
 
-# Model
+# model
 #---------------------------------------------------------------------------------------------------
 data(mcompd)
 data(sbp)
 data(psub)
 
-cilr <- compilr(data = mcompd[ID %in% 1:10, .SD[1:3], by = ID], sbp = sbp,
+cilr <- complr(data = mcompd[ID %in% 1:10, .SD[1:3], by = ID], sbp = sbp,
                 parts = c("TST", "WAKE", "MVPA", "LPA", "SB"), idvar = "ID", total = 1440)
 
 suppressWarnings(
-  m <- brmcoda(compilr = cilr,
+  m <- brmcoda(complr = cilr,
                formula = Stress ~ bilr1 + bilr2 + bilr3 + bilr4 +
                  wilr1 + wilr2 + wilr3 + wilr4 + Female + (1 | ID),
                chain = 1, iter = 500, seed = 123,
@@ -79,7 +79,7 @@ x <- bsub(object = m, basesub = psub, delta = 2)
 #   
 #   ## reference grid is provided for unadjusted model
 #   suppressWarnings(
-#     m2 <- brmcoda(compilr = cilr,
+#     m2 <- brmcoda(complr = cilr,
 #                   formula = Stress ~ bilr1 + bilr2 + bilr3 + bilr4 +
 #                     wilr1 + wilr2 + wilr3 + wilr4 + (1 | ID),
 #                   chain = 1, iter = 500, seed = 123,
@@ -137,11 +137,11 @@ x <- bsub(object = m, basesub = psub, delta = 2)
 #   expect_equal(x4, x5)
 #   
 #   ## keep prediction at each level of refrence grid 
-#   cilr <- compilr(data = mcompd[ID %in% c(1:5, 185:190), .SD[1:3], by = ID], sbp = sbp,
+#   cilr <- complr(data = mcompd[ID %in% c(1:5, 185:190), .SD[1:3], by = ID], sbp = sbp,
 #                   parts = c("TST", "WAKE", "MVPA", "LPA", "SB"), idvar = "ID", total = 1440)
 #   
 #   suppressWarnings(
-#     m <- brmcoda(compilr = cilr,
+#     m <- brmcoda(complr = cilr,
 #                  formula = Stress ~ bilr1 + bilr2 + bilr3 + bilr4 +
 #                    wilr1 + wilr2 + wilr3 + wilr4 + Female + (1 | ID),
 #                  chain = 1, iter = 500, seed = 123,
@@ -196,7 +196,7 @@ test_that("bsub outputs what expected", {
   
   ## types
   expect_type(x, "list")
-  expect_equal(length(x), length(m$CompILR$parts))
+  expect_equal(length(x), length(m$complr$parts))
   expect_s3_class(x$TST, "data.table")
   expect_s3_class(x$WAKE, "data.table")
   expect_s3_class(x$MVPA, "data.table")
@@ -304,18 +304,18 @@ test_that("bsub gives results in expected direction and magnitude", {
 test_that("bsub's results matches with brm model for 2-component composition (TST vs WAKE)", {
   
   sbp <- as.matrix(data.table(1, -1))
-  cilr <- compilr(data = mcompd[ID %in% 1:10, .SD[1:3], by = ID], sbp = sbp,
+  cilr <- complr(data = mcompd[ID %in% 1:10, .SD[1:3], by = ID], sbp = sbp,
                   parts = c("TST", "WAKE"), idvar = "ID", total = 1440)
   psub <- basesub(c("TST", "WAKE"))
   suppressWarnings(
-    m <- brmcoda(compilr = cilr,
+    m <- brmcoda(complr = cilr,
                  formula = Stress ~ bilr1 + wilr1 + (1 | ID),
                  chain = 1, iter = 500, seed = 123,
                  backend = "cmdstanr"))
   a <- bsub(object = m, basesub = psub, delta = 1:2)
   
   ## Estimates
-  if (isTRUE(suppressWarnings(summary(m$Model)$fixed[2, 1] > 0))) { 
+  if (isTRUE(suppressWarnings(summary(m$model)$fixed[2, 1] > 0))) { 
     expect_true(all(a$TST[From == "WAKE" & Delta > 1]$Mean > 0)) 
     expect_true(all(a$WAKE[From == "TST" & Delta > 1]$Mean < 0)) 
   } else {
@@ -325,7 +325,7 @@ test_that("bsub's results matches with brm model for 2-component composition (TS
   
   # CIs
   suppressWarnings(expect_true(
-    (0 %gele% c(summary(m$Model)$fixed[2, 3], summary(m$Model)$fixed[2, 4]))
+    (0 %gele% c(summary(m$model)$fixed[2, 3], summary(m$model)$fixed[2, 4]))
     == (0 %agele% c(a$TST[From == "WAKE" & Delta == 1]$CI_low,
                     a$TST[From == "WAKE" & Delta == 1]$CI_high))))
   
@@ -335,18 +335,18 @@ test_that("bsub's results matches with brm model for 2-component composition (TS
 test_that("bsub's results matches with brm model for 2-component composition (TST vs MVPA)", {
   
   sbp <- as.matrix(data.table(1, -1))
-  cilr <- compilr(data = mcompd[ID %in% 1:10, .SD[1:3], by = ID], sbp = sbp,
+  cilr <- complr(data = mcompd[ID %in% 1:10, .SD[1:3], by = ID], sbp = sbp,
                   parts = c("TST", "MVPA"), idvar = "ID", total = 1440)
   psub <- basesub(c("TST", "MVPA"))
   suppressWarnings(
-    m <- brmcoda(compilr = cilr,
+    m <- brmcoda(complr = cilr,
                  formula = Stress ~ bilr1 + wilr1 + (1 | ID),
                  chain = 1, iter = 500, seed = 123,
                  backend = "cmdstanr"))
   b <- bsub(object = m, basesub = psub, delta = 1:2)
   
   ## Estimates
-  if (isTRUE(suppressWarnings(summary(m$Model)$fixed[2, 1] > 0))) {
+  if (isTRUE(suppressWarnings(summary(m$model)$fixed[2, 1] > 0))) {
     expect_true(all(b$TST[From == "MVPA" & Delta > 1]$Mean > 0))
     expect_true(all(b$MVPA[From == "TST" & Delta > 1]$Mean < 0))
   } else {
@@ -356,7 +356,7 @@ test_that("bsub's results matches with brm model for 2-component composition (TS
 
   # CIs
   suppressWarnings(expect_true(
-    (0 %gele% c(summary(m$Model)$fixed[2, 3], summary(m$Model)$fixed[2, 4]))
+    (0 %gele% c(summary(m$model)$fixed[2, 3], summary(m$model)$fixed[2, 4]))
     == (0 %agele% c(b$TST[From == "MVPA" & Delta == 1]$CI_low,
                     b$TST[From == "MVPA" & Delta == 1]$CI_high))))
 
@@ -366,18 +366,18 @@ test_that("bsub's results matches with brm model for 2-component composition (TS
 test_that("bsub's results matches with brm model for 2-component composition (TST vs LPA)", {
 
   sbp <- as.matrix(data.table(1, -1))
-  cilr <- compilr(data = mcompd[ID %in% 1:10, .SD[1:3], by = ID], sbp = sbp,
+  cilr <- complr(data = mcompd[ID %in% 1:10, .SD[1:3], by = ID], sbp = sbp,
                   parts = c("TST", "LPA"), idvar = "ID", total = 1440)
   psub <- basesub(c("TST", "LPA"))
   suppressWarnings(
-    m <- brmcoda(compilr = cilr,
+    m <- brmcoda(complr = cilr,
                  formula = Stress ~ bilr1 + wilr1 + (1 | ID),
                  chain = 1, iter = 500, seed = 123,
                  backend = "cmdstanr"))
   c <- bsub(object = m, basesub = psub, delta = 1:2)
   
   ## Estimates
-  if (isTRUE(suppressWarnings(summary(m$Model)$fixed[2, 1] > 0))) {
+  if (isTRUE(suppressWarnings(summary(m$model)$fixed[2, 1] > 0))) {
     expect_true(all(c$TST[From == "LPA" & Delta > 1]$Mean > 0))
     expect_true(all(c$LPA[From == "TST" & Delta > 1]$Mean < 0))
   } else {
@@ -387,7 +387,7 @@ test_that("bsub's results matches with brm model for 2-component composition (TS
 
   # CIs
   suppressWarnings(expect_true(
-    (0 %gele% c(summary(m$Model)$fixed[2, 3], summary(m$Model)$fixed[2, 4]))
+    (0 %gele% c(summary(m$model)$fixed[2, 3], summary(m$model)$fixed[2, 4]))
     == (0 %agele% c(c$TST[From == "LPA" & Delta == 1]$CI_low,
                     c$TST[From == "LPA" & Delta == 1]$CI_high))))
 
@@ -397,18 +397,18 @@ test_that("bsub's results matches with brm model for 2-component composition (TS
 test_that("bsub's results matches with brm model for 2-component composition (TST vs SB)", {
 
   sbp <- as.matrix(data.table(1, -1))
-  cilr <- compilr(data = mcompd[ID %in% 1:10, .SD[1:3], by = ID], sbp = sbp,
+  cilr <- complr(data = mcompd[ID %in% 1:10, .SD[1:3], by = ID], sbp = sbp,
                   parts = c("TST", "SB"), idvar = "ID", total = 1440)
   psub <- basesub(c("TST", "SB"))
   suppressWarnings(
-    m <- brmcoda(compilr = cilr,
+    m <- brmcoda(complr = cilr,
                  formula = Stress ~ bilr1 + wilr1 + (1 | ID),
                  chain = 1, iter = 500, seed = 123,
                  backend = "cmdstanr"))
   d <- bsub(object = m, basesub = psub, delta = 1:2)
   
   ## Estimates
-  if (isTRUE(suppressWarnings(summary(m$Model)$fixed[2, 1] > 0))) {
+  if (isTRUE(suppressWarnings(summary(m$model)$fixed[2, 1] > 0))) {
     expect_true(all(d$TST[From == "SB" & Delta > 1]$Mean > 0))
     expect_true(all(d$SB[From == "TST" & Delta > 1]$Mean < 0))
   } else {
@@ -418,7 +418,7 @@ test_that("bsub's results matches with brm model for 2-component composition (TS
 
   # CIs
   suppressWarnings(expect_true(
-    (0 %gele% c(summary(m$Model)$fixed[2, 3], summary(m$Model)$fixed[2, 4]))
+    (0 %gele% c(summary(m$model)$fixed[2, 3], summary(m$model)$fixed[2, 4]))
     == (0 %agele% c(d$TST[From == "SB" & Delta == 1]$CI_low,
                     d$TST[From == "SB" & Delta == 1]$CI_high))))
 
@@ -428,19 +428,19 @@ test_that("bsub's results matches with brm model for 2-component composition (TS
 test_that("bsub's results matches with brm model for 2-component composition (WAKE vs MVPA)", {
 
   sbp <- as.matrix(data.table(1, -1))
-  cilr <- compilr(data = mcompd[ID %in% 1:10, .SD[1:3], by = ID], sbp = sbp,
+  cilr <- complr(data = mcompd[ID %in% 1:10, .SD[1:3], by = ID], sbp = sbp,
                   parts = c("WAKE", "MVPA"), idvar = "ID", total = 1440)
   psub <- basesub(c("WAKE", "MVPA"))
   
   suppressWarnings(
-    m <- brmcoda(compilr = cilr,
+    m <- brmcoda(complr = cilr,
                  formula = Stress ~ bilr1 + wilr1 + (1 | ID),
                  chain = 1, iter = 500, seed = 123,
                  backend = "cmdstanr"))
   e <- bsub(object = m, basesub = psub, delta = 1:2)
   
   ## Estimates
-  if (isTRUE(suppressWarnings(summary(m$Model)$fixed[2, 1] > 0))) {
+  if (isTRUE(suppressWarnings(summary(m$model)$fixed[2, 1] > 0))) {
     expect_true(all(e$WAKE[From == "MVPA" & Delta > 1]$Mean > 0))
     expect_true(all(e$MVPA[From == "WAKE" & Delta > 1]$Mean < 0))
   } else {
@@ -450,7 +450,7 @@ test_that("bsub's results matches with brm model for 2-component composition (WA
 
   # CIs
   suppressWarnings(expect_true(
-    (0 %gele% c(summary(m$Model)$fixed[2, 3], summary(m$Model)$fixed[2, 4]))
+    (0 %gele% c(summary(m$model)$fixed[2, 3], summary(m$model)$fixed[2, 4]))
     == (0 %agele% c(e$WAKE[From == "MVPA" & Delta == 1]$CI_low,
                     e$WAKE[From == "MVPA" & Delta == 1]$CI_high))))
 
@@ -460,18 +460,18 @@ test_that("bsub's results matches with brm model for 2-component composition (WA
 test_that("bsub's results matches with brm model for 2-component composition (WAKE vs LPA)", {
 
   sbp <- as.matrix(data.table(1, -1))
-  cilr <- compilr(data = mcompd[ID %in% 1:10, .SD[1:3], by = ID], sbp = sbp,
+  cilr <- complr(data = mcompd[ID %in% 1:10, .SD[1:3], by = ID], sbp = sbp,
                   parts = c("WAKE", "LPA"), idvar = "ID", total = 1440)
   psub <- basesub(c("WAKE", "LPA"))
   suppressWarnings(
-    m <- brmcoda(compilr = cilr,
+    m <- brmcoda(complr = cilr,
                  formula = Stress ~ bilr1 + wilr1 + (1 | ID),
                  chain = 1, iter = 500, seed = 123,
                  backend = "cmdstanr"))
   f <- bsub(object = m, basesub = psub, delta = 1:2)
   
   ## Estimates
-  if (isTRUE(suppressWarnings(summary(m$Model)$fixed[2, 1] > 0))) {
+  if (isTRUE(suppressWarnings(summary(m$model)$fixed[2, 1] > 0))) {
     expect_true(all(f$WAKE[From == "LPA" & Delta > 1]$Mean > 0))
     expect_true(all(f$LPA[From == "WAKE" & Delta > 1]$Mean < 0))
   } else {
@@ -481,7 +481,7 @@ test_that("bsub's results matches with brm model for 2-component composition (WA
 
   # CIs
   suppressWarnings(expect_true(
-    (0 %gele% c(summary(m$Model)$fixed[2, 3], summary(m$Model)$fixed[2, 4]))
+    (0 %gele% c(summary(m$model)$fixed[2, 3], summary(m$model)$fixed[2, 4]))
     == (0 %agele% c(f$WAKE[From == "LPA" & Delta == 1]$CI_low,
                     f$WAKE[From == "LPA" & Delta == 1]$CI_high))))
 
@@ -491,18 +491,18 @@ test_that("bsub's results matches with brm model for 2-component composition (WA
 test_that("bsub's results matches with brm model for 2-component composition (WAKE vs SB)", {
 
   sbp <- as.matrix(data.table(1, -1))
-  cilr <- compilr(data = mcompd[ID %in% 1:10, .SD[1:3], by = ID], sbp = sbp,
+  cilr <- complr(data = mcompd[ID %in% 1:10, .SD[1:3], by = ID], sbp = sbp,
                   parts = c("WAKE", "SB"), idvar = "ID", total = 1440)
   psub <- basesub(c("WAKE", "SB"))
   suppressWarnings(
-    m <- brmcoda(compilr = cilr,
+    m <- brmcoda(complr = cilr,
                  formula = Stress ~ bilr1 + wilr1 + (1 | ID),
                  chain = 1, iter = 500, seed = 123,
                  backend = "cmdstanr"))
   g <- bsub(object = m, basesub = psub, delta = 1:2)
   
   ## Estimates
-  if (isTRUE(suppressWarnings(summary(m$Model)$fixed[2, 1] > 0))) {
+  if (isTRUE(suppressWarnings(summary(m$model)$fixed[2, 1] > 0))) {
     expect_true(all(g$WAKE[From == "SB" & Delta > 1]$Mean > 0))
     expect_true(all(g$SB[From == "WAKE" & Delta > 1]$Mean < 0))
   } else {
@@ -512,7 +512,7 @@ test_that("bsub's results matches with brm model for 2-component composition (WA
 
   # CIs
   suppressWarnings(expect_true(
-    (0 %gele% c(summary(m$Model)$fixed[2, 3], summary(m$Model)$fixed[2, 4]))
+    (0 %gele% c(summary(m$model)$fixed[2, 3], summary(m$model)$fixed[2, 4]))
     == (0 %agele% c(g$WAKE[From == "SB" & Delta == 1]$CI_low,
                     g$WAKE[From == "SB" & Delta == 1]$CI_high))))
 
@@ -522,17 +522,17 @@ test_that("bsub's results matches with brm model for 2-component composition (WA
 test_that("bsub's results matches with brm model for 2-component composition (MVPA vs LPA)", {
 
   sbp <- as.matrix(data.table(1, -1))
-  cilr <- compilr(data = mcompd[ID %in% 1:10, .SD[1:3], by = ID], sbp = sbp,
+  cilr <- complr(data = mcompd[ID %in% 1:10, .SD[1:3], by = ID], sbp = sbp,
                   parts = c("MVPA", "LPA"), idvar = "ID", total = 1440)
   psub <- basesub(c("MVPA", "LPA"))
-  suppressWarnings(m <- brmcoda(compilr = cilr,
+  suppressWarnings(m <- brmcoda(complr = cilr,
                                 formula = Stress ~ bilr1 + wilr1 + (1 | ID),
                                 chain = 1, iter = 500, seed = 123,
                                 backend = "cmdstanr"))
   h <- bsub(object = m, basesub = psub, delta = 1:2)
   
   ## Estimates
-  if (isTRUE(suppressWarnings(summary(m$Model)$fixed[2, 1] > 0))) {
+  if (isTRUE(suppressWarnings(summary(m$model)$fixed[2, 1] > 0))) {
     expect_true(all(h$MVPA[From == "LPA" & Delta > 1]$Mean > 0))
     expect_true(all(h$LPA[From == "MVPA" & Delta > 1]$Mean < 0))
   } else {
@@ -542,7 +542,7 @@ test_that("bsub's results matches with brm model for 2-component composition (MV
 
   # CIs
   suppressWarnings(expect_true(
-    (0 %gele% c(summary(m$Model)$fixed[2, 3], summary(m$Model)$fixed[2, 4]))
+    (0 %gele% c(summary(m$model)$fixed[2, 3], summary(m$model)$fixed[2, 4]))
     == (0 %agele% c(h$MVPA[From == "LPA" & Delta == 1]$CI_low,
                     h$MVPA[From == "LPA" & Delta == 1]$CI_high))))
 
@@ -552,18 +552,18 @@ test_that("bsub's results matches with brm model for 2-component composition (MV
 test_that("bsub's results matches with brm model for 2-component composition (MVPA vs SB)", {
 
   sbp <- as.matrix(data.table(1, -1))
-  cilr <- compilr(data = mcompd[ID %in% 1:10, .SD[1:3], by = ID], sbp = sbp,
+  cilr <- complr(data = mcompd[ID %in% 1:10, .SD[1:3], by = ID], sbp = sbp,
                   parts = c("MVPA", "SB"), idvar = "ID", total = 1440)
   psub <- basesub(c("MVPA", "SB"))
   suppressWarnings(
-    m <- brmcoda(compilr = cilr,
+    m <- brmcoda(complr = cilr,
                  formula = Stress ~ bilr1 + wilr1 + (1 | ID),
                  chain = 1, iter = 500, seed = 123,
                  backend = "cmdstanr"))
   i <- bsub(object = m, basesub = psub, delta = 1:2)
   
   ## Estimates
-  if (isTRUE(suppressWarnings(summary(m$Model)$fixed[2, 1] > 0))) {
+  if (isTRUE(suppressWarnings(summary(m$model)$fixed[2, 1] > 0))) {
     expect_true(all(i$MVPA[From == "SB" & Delta > 1]$Mean > 0))
     expect_true(all(i$SB[From == "MVPA" & Delta > 1]$Mean < 0))
   } else {
@@ -573,7 +573,7 @@ test_that("bsub's results matches with brm model for 2-component composition (MV
 
   # CIs
   suppressWarnings(expect_true(
-    (0 %gele% c(summary(m$Model)$fixed[2, 3], summary(m$Model)$fixed[2, 4]))
+    (0 %gele% c(summary(m$model)$fixed[2, 3], summary(m$model)$fixed[2, 4]))
     == (0 %agele% c(i$MVPA[From == "SB" & Delta == 1]$CI_low,
                     i$MVPA[From == "SB" & Delta == 1]$CI_high))))
 
@@ -583,11 +583,11 @@ test_that("bsub's results matches with brm model for 2-component composition (MV
 test_that("bsub's results matches with brm model for 2-component composition (LPA vs SB)", {
 
   sbp <- as.matrix(data.table(1, -1))
-  cilr <- compilr(data = mcompd[ID %in% 1:10, .SD[1:3], by = ID], sbp = sbp,
+  cilr <- complr(data = mcompd[ID %in% 1:10, .SD[1:3], by = ID], sbp = sbp,
                   parts = c("LPA", "SB"), idvar = "ID", total = 1440)
   psub <- basesub(c("LPA", "SB"))
   suppressWarnings(
-    m <- brmcoda(compilr = cilr,
+    m <- brmcoda(complr = cilr,
                  formula = Stress ~ bilr1 + wilr1 + (1 | ID),
                  chain = 1, iter = 500, seed = 123,
                  backend = "cmdstanr"))
@@ -595,7 +595,7 @@ test_that("bsub's results matches with brm model for 2-component composition (LP
   
   
   ## Estimates
-  if (isTRUE(suppressWarnings(summary(m$Model)$fixed[2, 1] > 0))) {
+  if (isTRUE(suppressWarnings(summary(m$model)$fixed[2, 1] > 0))) {
     expect_true(all(j$LPA[From == "SB" & Delta > 1]$Mean > 0))
     expect_true(all(j$SB[From == "LPA" & Delta > 1]$Mean < 0))
   } else {
@@ -605,7 +605,7 @@ test_that("bsub's results matches with brm model for 2-component composition (LP
 
   # CIs
   suppressWarnings(expect_true(
-    (0 %gele% c(summary(m$Model)$fixed[2, 3], summary(m$Model)$fixed[2, 4]))
+    (0 %gele% c(summary(m$model)$fixed[2, 3], summary(m$model)$fixed[2, 4]))
     == (0 %agele% c(j$LPA[From == "SB" & Delta == 1]$CI_low,
                     j$LPA[From == "SB" & Delta == 1]$CI_high))))
 
@@ -622,10 +622,10 @@ test_that("bsub's results matches with brm model for 2-component composition (LP
 # 
 # # model as usual
 # data("sbp")
-# cilr <- compilr(data = mcompd, sbp = sbp,
+# cilr <- complr(data = mcompd, sbp = sbp,
 #                 parts = c("TST", "WAKE", "MVPA", "LPA", "SB"), idvar = "ID", total = 1440)
 # 
-# suppressWarnings(m <- brmcoda(compilr = cilr,
+# suppressWarnings(m <- brmcoda(complr = cilr,
 #                               formula = Stress ~ bilr1 + bilr2 + bilr3 + bilr4 +
 #                                 wilr1 + wilr2 + wilr3 + wilr4 + Female + (1 | ID),
 #                               chain = 10, iter = 10000, cores = 8, seed = 123))
@@ -638,10 +638,10 @@ test_that("bsub's results matches with brm model for 2-component composition (LP
 #   0, 1, 1, -1, 0,
 #   0, 1, -1, 0, 0), ncol = 5, byrow = TRUE)
 # 
-# cilr <- compilr(data = mcompd, sbp = sbp,
+# cilr <- complr(data = mcompd, sbp = sbp,
 #                 parts = c("TST", "WAKE", "MVPA", "LPA", "SB"), idvar = "ID", total = 1440)
 # 
-# suppressWarnings(m <- brmcoda(compilr = cilr,
+# suppressWarnings(m <- brmcoda(complr = cilr,
 #                               formula = Stress ~ bilr1 + bilr2 + bilr3 + bilr4 +
 #                                 wilr1 + wilr2 + wilr3 + wilr4 + Female + (1 | ID),
 #                               chain = 10, iter = 10000, cores = 8, seed = 123))
